@@ -1,5 +1,6 @@
 """Logging configuration and utilities."""
 
+import contextlib
 import logging as python_logging
 import os
 import typing as t
@@ -14,7 +15,7 @@ from pydantic_settings import BaseSettings, SettingsConfigDict
 from rich.console import Console
 from rich.logging import RichHandler
 
-from ._constants import __env_file__, __project_name__
+from ._constants import __env_file__, __is_running_in_read_only_environment__, __project_name__
 from ._settings import load_settings
 
 
@@ -62,12 +63,14 @@ def _validate_file_name(file_name: str | None) -> str | None:
             raise ValueError(message)
     else:
         try:
-            file_path.touch(exist_ok=False)
-            file_path.unlink()
+            file_path.touch(exist_ok=True)
         except OSError as e:
             message = f"File {file_path.absolute()} cannot be created: {e}"
             raise ValueError(message) from e
 
+        with contextlib.suppress(OSError):  # Parallel execution e.g. in tests can create race
+            file_path.unlink()
+
     return file_name
 
 
@@ -92,7 +95,10 @@ class LogSettings(BaseSettings):
     file_name: Annotated[
         str,
         AfterValidator(_validate_file_name),
-        Field(description="Name of the log file", default=f"{__project_name__}.log"),
+        Field(
+            description="Name of the log file",
+            default="/dev/stdout" if __is_running_in_read_only_environment__ else f"{__project_name__}.log",
+        ),
     ]
     console_enabled: Annotated[
         bool,
